# Sensa
[![Test & Build](https://github.com/Tensor46/sensa/actions/workflows/python-package.yml/badge.svg?branch=main)](https://github.com/Tensor46/sensa/actions/workflows/python-package.yml)

Sensa (from the Latin sēnsus, meaning “perception”): A PyTorch Lightning based library providing Masked Autoencoder (MAE) pretraining and classification training using customizable Vision Transformer (ViT) backbones.

### Features
* Masked Autoencoder Pretraining with random token masking and reconstruction.
* Classification Training with flexible pooling strategies (avg, full, half, token).

### License
MIT License
